@@ -99,6 +99,7 @@ struct app_conn_t {
   /* Radius authentication stuff */
   /* Parameters are initialised whenever a reply to an access request
      is received. */
+#ifdef ENABLE_RADPROXY
   uint8_t chal[MAX_EAP_LEN];     /* EAP challenge */
   size_t challen;                /* Length of EAP challenge */
   uint8_t sendkey[RADIUS_ATTR_VLEN];
@@ -111,6 +112,7 @@ struct app_conn_t {
   uint32_t types;
   uint8_t ms2succ[MS2SUCCSIZE];
   size_t ms2succlen;
+#endif
 
   /* Radius proxy stuff */
   /* Parameters are initialised whenever a radius proxy request is received */
@@ -130,8 +132,11 @@ struct app_conn_t {
   uint8_t hismac[PKT_ETH_ALEN];/* His MAC address */
   struct in_addr ourip;        /* IP address to listen to */
   struct in_addr hisip;        /* Client IP address */
+  struct in_addr hismask;      /* Client IP address mask */
   struct in_addr reqip;        /* IP requested by client */
+#ifdef ENABLE_UAMANYIP
   struct in_addr natip;
+#endif
   uint16_t mtu;
 
   /* Information for each connection */
@@ -145,6 +150,15 @@ struct app_conn_t {
   char uamexit;
 };
 
+#define VAL_STRING   0
+#define VAL_IN_ADDR  1
+#define VAL_MAC_ADDR 2
+#define VAL_ULONG    3
+#define VAL_ULONG64  4
+#define VAL_USHORT   5
+
+int set_env(char *name, char type, void *value, int len);
+
 extern struct app_conn_t *firstfreeconn; /* First free in linked list */
 extern struct app_conn_t *lastfreeconn;  /* Last free in linked list */
 extern struct app_conn_t *firstusedconn; /* First used in linked list */
@@ -164,6 +178,8 @@ struct chilli_peer {
 #define PEER_STATE_OFFLINE 0
 #define PEER_STATE_ACTIVE  1
 #define PEER_STATE_STANDBY 2
+#define PEER_STATE_ADMCMD  3
+#define PEER_STATE_MODULE  4
 #endif
 
 #ifdef ENABLE_STATFILE
@@ -199,6 +215,10 @@ int chilli_new_conn(struct app_conn_t **conn);
 
 int chilli_assign_snat(struct app_conn_t *appconn, int force);
 
+void chilli_print(bstring s, int listfmt, 
+		  struct app_conn_t *appconn,
+		  struct dhcp_conn_t *conn);
+
 int chilli_acct_fromsub(struct app_conn_t *appconn, size_t len);
 int chilli_acct_tosub(struct app_conn_t *appconn, size_t len);
 
@@ -276,6 +296,9 @@ int runscript(struct app_conn_t *appconn, char* script);
 int statedir_file(char *dst, int dlen, char *file, char *deffile);
 int bblk_fromfd(bstring s, int fd, int len);
 int bstring_fromfd(bstring s, int fd);
+#ifndef HAVE_GETLINE
+ssize_t getline (char** lineptr, size_t* n, FILE* stream);
+#endif
 
 /* sig.c */
 int ndelay_on (int fd);
