@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2007-2009 Coova Technologies, LLC. <support@coova.com>
+ * Copyright (C) 2007-2011 Coova Technologies, LLC. <support@coova.com>
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ struct conn_t {
   bstring write_buf;
   int write_pos;
 
+  time_t start_time;
+
 #ifdef HAVE_SSL
   openssl_con * sslcon;
 #endif
@@ -63,4 +65,8 @@ int conn_close(struct conn_t *conn);
 
 void conn_bstring_readhandler(struct conn_t *conn, bstring data);
 
+int conn_select_fd(struct conn_t *conn, select_ctx *sctx);
+int conn_update_write(struct conn_t *conn);
+int conn_select_update(struct conn_t *conn, select_ctx *sctx);
+
 #endif
