@@ -274,6 +274,9 @@ int options_fromfd(int fd, bstring bt) {
   if (!option_s_l(bt, &o.condown)) return 0;
   if (!option_s_l(bt, &o.macup)) return 0;
   if (!option_s_l(bt, &o.macdown)) return 0;
+#ifdef ENABLE_IEEE8021Q
+  if (!option_s_l(bt, &o.vlanupdate)) return 0;
+#endif
 
   if (!option_s_l(bt, &o.radiussecret)) return 0;
   if (!option_s_l(bt, &o.radiusnasid)) return 0;
@@ -446,6 +449,9 @@ int options_save(char *file, bstring bt) {
   if (!option_s_s(bt, &o.condown)) return 0;
   if (!option_s_s(bt, &o.macup)) return 0;
   if (!option_s_s(bt, &o.macdown)) return 0;
+#ifdef ENABLE_IEEE8021Q
+  if (!option_s_s(bt, &o.vlanupdate)) return 0;
+#endif
 
   if (!option_s_s(bt, &o.radiussecret)) return 0;
   if (!option_s_s(bt, &o.radiusnasid)) return 0;
