@@ -89,7 +89,7 @@
 #define REDIR_MSG_NSESSIONID  4
 
 struct eapmsg_t {
-  uint8_t len;
+  uint16_t len;
   uint8_t data[MAX_EAP_LEN];
 };
 
@@ -204,6 +204,11 @@ typedef struct _redir_request {
 #define REDIR_CONN_FD   (1<<1)
   char state;
 
+#ifdef ENABLE_REDIRINJECT
+#define REDIRINJECT_MAX 256
+  char inject_url[REDIRINJECT_MAX];
+#endif
+
   struct _redir_request *prev, *next;
 
 } redir_request;
@@ -225,7 +230,9 @@ struct redir_t {
 #endif
   struct in_addr addr;
   int port;
+#ifdef ENABLE_UAMUIPORT
   int uiport;
+#endif
   
   int starttime;
   
