@@ -24,15 +24,14 @@
 /*
  *   I do not like this here, but otherwise
  *   __u64 is not defined. Set by -ansi
+#undef __STRICT_ANSI__
  */
 
-#undef __STRICT_ANSI__
-
+#include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
 #include <ctype.h>
-#include <stdarg.h>
 
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -222,6 +221,10 @@
 #include <regex.h>
 #endif
 
+#ifdef HAVE_IFADDRS_H
+#include <ifaddrs.h>
+#endif
+
 #undef LITTLE_ENDIAN
 #undef BIG_ENDIAN
 
@@ -249,9 +252,6 @@
 #define safe_snprintf portable_snprintf
 char *safe_strncpy(char *dst, const char *src, size_t size);
 
-/* XXX */
-#define ENABLE_IPV6 1
-
 #ifndef TEMP_FAILURE_RETRY
 #define TEMP_FAILURE_RETRY(expression) \
     ({ \
